View source: R/gets-isat-source.R
| create.ISmatrices | R Documentation |
Internal function that constructs a list of indicator matrices used in indicator
saturation (IIS, SIS, TIS, UIS) to be passed back towards isat.
create.ISmatrices(iis, sis, tis, uis, y.n, y.index.as.char)
iis |
Logical values indicating whether to generate Impulse indicators. |
sis |
Logical values indicating whether to generate Step indicators. |
tis |
Logical values indicating whether to generate Trend indicators. |
uis |
Taking the |
y.n |
Sample size. |
y.index.as.char |
The index of y as a character vector to retain any implied time series structure. |
A list object containing the required indicator matrices.
See Also isat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.