View source: R/gets-isat-source.R
| as.isat | R Documentation |
Experimental function to convert 'arx'/'gets' object to 'isat' object. Note that this conversion will naturally differ from a genuine 'isat' object, especially with regard to the list elements of the object that describe the saturation algorithm (paths, best.terminal, no.of.estimations, etc.). So please use with care.
as.isat(object, indicator_regex = list(iis = "^iis", sis = "^sis",
tis = "^tis", uis = "^uis"), ...)
object |
object of class |
indicator_regex |
List of regular expressions to identify the indicators in the object. The default is |
... |
Additional arguments passed to |
Object of class isat
Moritz Schwarz, https://www.moritzschwarz.org/
arx, gets, isat
##generate data, estimate model of class 'arx':
set.seed(123)
y <- rnorm(30)
arxmod <- arx(y, mc=TRUE, ar=1:3)
as.isat(arxmod)
##from 'gets' to 'lm':
getsmod <- getsm(arxmod, keep=1)
as.isat(getsmod)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.