Learn R Programming

gets (version 0.40)

as.isat: Convert to 'isat' object

Description

Experimental function to convert 'arx'/'gets' object to 'isat' object. Note that this conversion will naturally differ from a genuine 'isat' object, especially with regard to the list elements of the object that describe the saturation algorithm (paths, best.terminal, no.of.estimations, etc.). So please use with care.

Usage

as.isat(object, indicator_regex = list(iis = "^iis", sis = "^sis", 
tis = "^tis", uis = "^uis"), ...)

Value

Object of class isat

Arguments

object

object of class arx or gets

indicator_regex

List of regular expressions to identify the indicators in the object. The default is list(iis = "^iis", sis = "^sis", tis = "^tis", uis = "^uis").

...

Additional arguments passed to isat.

Author

Moritz Schwarz, https://www.moritzschwarz.org/

See Also

arx, gets, isat

Examples

Run this code
##generate data, estimate model of class 'arx':
set.seed(123)
y <- rnorm(30)
arxmod <- arx(y, mc=TRUE, ar=1:3)
as.isat(arxmod)

##from 'gets' to 'lm':
getsmod <- getsm(arxmod, keep=1)
as.isat(getsmod)

Run the code above in your browser using DataLab