Learn R Programming

gets (version 0.40)

create.ISmatrices: Internal function to construct Indicator Saturation Matrices

Description

Internal function that constructs a list of indicator matrices used in indicator saturation (IIS, SIS, TIS, UIS) to be passed back towards isat.

Usage

create.ISmatrices(iis, sis, tis, uis, y.n, y.index.as.char)

Value

A list object containing the required indicator matrices.

Arguments

iis

Logical values indicating whether to generate Impulse indicators.

sis

Logical values indicating whether to generate Step indicators.

tis

Logical values indicating whether to generate Trend indicators.

uis

Taking the uis argument from isat for to process further.

y.n

Sample size.

y.index.as.char

The index of y as a character vector to retain any implied time series structure.

See Also

See Also isat