Internal function that constructs a list of indicator matrices used in indicator
saturation (IIS, SIS, TIS, UIS) to be passed back towards isat.
create.ISmatrices(iis, sis, tis, uis, y.n, y.index.as.char)A list object containing the required indicator matrices.
Logical values indicating whether to generate Impulse indicators.
Logical values indicating whether to generate Step indicators.
Logical values indicating whether to generate Trend indicators.
Taking the uis argument from isat for to process further.
Sample size.
The index of y as a character vector to retain any implied time series structure.
See Also isat